package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.Dksq;

/**
 * 贷款申请_主Mapper接口
 * 
 * @author boman
 * @date 2023-06-15
 */
public interface DksqMapper 
{
    /**
     * 查询贷款申请_主
     * 
     * @param id 贷款申请_主主键
     * @return 贷款申请_主
     */
    public Dksq selectDksqById(Long id);

    /**
     * 查询贷款申请_主列表
     * 
     * @param dksq 贷款申请_主
     * @return 贷款申请_主集合
     */
    public List<Dksq> selectDksqList(Dksq dksq);

    /**
     * 新增贷款申请_主
     * 
     * @param dksq 贷款申请_主
     * @return 结果
     */
    public int insertDksq(Dksq dksq);

    /**
     * 修改贷款申请_主
     * 
     * @param dksq 贷款申请_主
     * @return 结果
     */
    public int updateDksq(Dksq dksq);

    /**
     * 删除贷款申请_主
     * 
     * @param id 贷款申请_主主键
     * @return 结果
     */
    public int deleteDksqById(Long id);

    /**
     * 批量删除贷款申请_主
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDksqByIds(Long[] ids);
}
